@@ -4,6 +4,9 @@
 */
 
 #include "newmailnotificationhistorybrowsertext.h"
+using namespace Qt::Literals::StringLiterals;
+
+#include "newmailnotifier_debug.h"
 #include "newmailnotifieropenfolderjob.h"
 #include "newmailnotifiershowmessagejob.h"
 
@@ -23,15 +26,17 @@ void NewMailNotificationHistoryBrowserText::doSetSource(const QUrl &url, QTextDo
 {
     Q_UNUSED(type);
     QString uri = url.toString();
-    // qDebug() << " uri " << uri;
-    if (uri.startsWith(QLatin1String("openmail:"))) {
+    qCDebug(NEWMAILNOTIFIER_LOG) << " uri " << uri;
+    if (uri.startsWith("openmail:"_L1)) {
         uri.remove(QStringLiteral("openmail:"));
-        // qDebug() << "openMail uri " << uri;
+        qCDebug(NEWMAILNOTIFIER_LOG) << "openMail uri " << uri;
         Q_EMIT openMail(uri);
-    } else if (uri.startsWith(QLatin1String("openfolder:"))) {
+    } else if (uri.startsWith("openfolder:"_L1)) {
         uri.remove(QStringLiteral("openfolder:"));
-        // qDebug() << "openFolder uri " << uri;
+        qCDebug(NEWMAILNOTIFIER_LOG) << "openFolder uri " << uri;
         Q_EMIT openFolder(uri);
+    } else {
+        qCWarning(NEWMAILNOTIFIER_LOG) << "No implement support for " << uri;
     }
 }
 
